
# Slot: has messages




URI: [http://example.org/sample/example1/has_messages](http://example.org/sample/example1/has_messages)


## Domain and Range

None &#8594;  <sub>0..1</sub> [String](types/String.md)

## Parents


## Children


## Used by

 * [HasMessagesChild](HasMessagesChild.md)
 * [HasMessagesClass](HasMessagesClass.md)
 * [MetricResult](MetricResult.md)
 * [MetricResultChild](MetricResultChild.md)
